src.nth.io/

summaryrefslogtreecommitdiff
path: root/main/state_machine.c
diff options
context:
space:
mode:
Diffstat (limited to 'main/state_machine.c')
-rw-r--r--main/state_machine.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/main/state_machine.c b/main/state_machine.c
index c9e4367..3d95308 100644
--- a/main/state_machine.c
+++ b/main/state_machine.c
@@ -63,9 +63,9 @@ esp_err_t state_machine_set(viewport_run_state_t target)
display_wake();
// Content choice: configured devices show "Loading…" until
// Scrypted pushes a /frame; unconfigured devices show the
// identity screen since there's no Scrypted to push anything.
if (configured) local_screens_show_loading();
- else local_screens_show_ip();
+ else local_screens_show_info();
}
arm_idle_timer_unlocked();
ESP_LOGI(TAG, "AWAKE (%s)", configured ? "configured" : "unconfigured");
@@ -63,9 +63,9 @@ esp_err_t state_machine_set(viewport_run_state_t target)
// Content choice: configured devices show "Loading…" until
// Scrypted pushes a /frame; unconfigured devices show the
- // identity screen since there's no Scrypted to push anything.
+ // info screen since there's no Scrypted to push anything.
if (configured) local_screens_show_loading();